Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(790)

Unified Diff: runtime/vm/object.h

Issue 2859673002: Pass type argument vector to generic functions (if --reify-generic-functions is (Closed)
Patch Set: address review comments and sync Created 3 years, 7 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « runtime/vm/kernel_to_il.cc ('k') | runtime/vm/object.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: runtime/vm/object.h
diff --git a/runtime/vm/object.h b/runtime/vm/object.h
index 603467775b9072d2a688818e3bf1ac6d66e6ecaa..3bb0676ad323a7c8eb9e4e5d12b43c3ea91f0d19 100644
--- a/runtime/vm/object.h
+++ b/runtime/vm/object.h
@@ -2647,14 +2647,16 @@ class Function : public Object {
// Returns true if the argument counts are valid for calling this function.
// Otherwise, it returns false and the reason (if error_message is not NULL).
- bool AreValidArgumentCounts(intptr_t num_arguments,
+ bool AreValidArgumentCounts(intptr_t num_type_arguments,
+ intptr_t num_arguments,
intptr_t num_named_arguments,
String* error_message) const;
// Returns true if the total argument count and the names of optional
// arguments are valid for calling this function.
// Otherwise, it returns false and the reason (if error_message is not NULL).
- bool AreValidArguments(intptr_t num_arguments,
+ bool AreValidArguments(intptr_t num_type_arguments,
+ intptr_t num_arguments,
const Array& argument_names,
String* error_message) const;
bool AreValidArguments(const ArgumentsDescriptor& args_desc,
@@ -2647,14 +2647,16 @@ class Function : public Object {
intptr_t num_named_arguments,
String* error_message) const;
- // Returns true if the total argument count and the names of optional
- // arguments are valid for calling this function.
+ // Returns true if the type argument count, total argument count and the names
+ // of optional arguments are valid for calling this function.
// Otherwise, it returns false and the reason (if error_message is not NULL).
« no previous file with comments | « runtime/vm/kernel_to_il.cc ('k') | runtime/vm/object.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698